==> jc-tke-metadata-1.1.415-sources.jar: com/xforceplus/ultraman/app/jctke/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.jctke.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2022-12-09
 */

public class PageMeta {
    public interface PurchaseOrderManagement {
        static String code() {
            return "purchaseOrderManagement";
        }
        static String name() {
            return "采购单管理";
        }
    }
    public interface GoodsReceiptManagement {
        static String code() {
            return "goodsReceiptManagement";
        }
        static String name() {
            return "收货单运维";
        }
    }
    public interface InvoiceNotice {
        static String code() {
            return "invoiceNotice";
        }
        static String name() {
            return "开票通知单#供应商专用";
        }
    }
    public interface TaxCode {
        static String code() {
            return "taxCode";
        }
        static String name() {
            return "税码关系配置";
        }
    }
    public interface SubeiAmountApproval {
        static String code() {
            return "subeiAmountApproval";
        }
        static String name() {
            return "诉讼费备用金模板审批人规则";
        }
    }
    public interface ToubaoAmountApproval {
        static String code() {
            return "toubaoAmountApproval";
        }
        static String name() {
            return "投标保证金模板审批人规则";
        }
    }
    public interface WeiAmountApproval {
        static String code() {
            return "weiAmountApproval";
        }
        static String name() {
            return "维保金模板审批人规则";
        }
    }
    public interface RpaTask {
        static String code() {
            return "rpaTask";
        }
        static String name() {
            return "RPA任务表";
        }
    }
    public interface ProfitCenterCompany {
        static String code() {
            return "profitCenterCompany";
        }
        static String name() {
            return "利润中心分公司关系管理";
        }
    }
    public interface AdvanceChargeInterface {
        static String code() {
            return "advanceChargeInterface";
        }
        static String name() {
            return "预付款履历";
        }
    }
    public interface AccountsPayableInterface {
        static String code() {
            return "accountsPayableInterface";
        }
        static String name() {
            return "应付款履历";
        }
    }
    public interface ApprovalHistory {
        static String code() {
            return "approvalHistory";
        }
        static String name() {
            return "付款单操作履历";
        }
    }
    public interface Enclosure {
        static String code() {
            return "enclosure";
        }
        static String name() {
            return "附件表";
        }
    }
    public interface PaymentManage {
        static String code() {
            return "paymentManage";
        }
        static String name() {
            return "付款申请单";
        }
    }
    public interface PurchaseOrder {
        static String code() {
            return "purchaseOrder";
        }
        static String name() {
            return "采购单主信息列表";
        }
    }
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票登记表";
        }
    }
    public interface InvoiceNoticeBill4Payment {
        static String code() {
            return "invoiceNoticeBill4Payment";
        }
        static String name() {
            return "开票通知单#生成应付单专用";
        }
    }
    public interface PoList {
        static String code() {
            return "poList";
        }
        static String name() {
            return "采购单列表#含PO预付款";
        }
    }
    public interface ApprovalRules {
        static String code() {
            return "approvalRules";
        }
        static String name() {
            return "付款单审批规则";
        }
    }
    public interface CostCenter {
        static String code() {
            return "costCenter";
        }
        static String name() {
            return "成本中心管理(废弃)";
        }
    }
    public interface CostCenterNew {
        static String code() {
            return "costCenterNew";
        }
        static String name() {
            return "成本中心";
        }
    }
    public interface LegalFees {
        static String code() {
            return "legalFees";
        }
        static String name() {
            return "诉讼费列表";
        }
    }
    public interface MatchInvoiceNoticeBill {
        static String code() {
            return "matchInvoiceNoticeBill";
        }
        static String name() {
            return "开票通知单#非协同配单专用";
        }
    }
    public interface MacthInvoice {
        static String code() {
            return "macthInvoice";
        }
        static String name() {
            return "发票配单";
        }
    }
    public interface Wbs {
        static String code() {
            return "wbs";
        }
        static String name() {
            return "WBS梯台运维";
        }
    }
    public interface PoRpaTask {
        static String code() {
            return "poRpaTask";
        }
        static String name() {
            return "RPA任务列表#抓取PO";
        }
    }
    public interface AgentFeeReport {
        static String code() {
            return "agentFeeReport";
        }
        static String name() {
            return "PowerBI运维";
        }
    }
    public interface MultiValues {
        static String code() {
            return "multiValues";
        }
        static String name() {
            return "多值测试";
        }
    }
    public interface PurchaseOrderInit {
        static String code() {
            return "purchaseOrderInit";
        }
        static String name() {
            return "采购单运维";
        }
    }
    public interface PuchaserAndReceived {
        static String code() {
            return "puchaserAndReceived";
        }
        static String name() {
            return "采购单—收货单管理";
        }
    }
    public interface InvoiceOperation {
        static String code() {
            return "invoiceOperation";
        }
        static String name() {
            return "发票操作履历";
        }
    }
    public interface ExchangeTicketsMatch {
        static String code() {
            return "exchangeTicketsMatch";
        }
        static String name() {
            return "开票通知单#换票配单";
        }
    }
    public interface AdvancedOrder {
        static String code() {
            return "advancedOrder";
        }
        static String name() {
            return "预付款列表";
        }
    }
    public interface ReplacePOList {
        static String code() {
            return "replacePOList";
        }
        static String name() {
            return "采购单列表#替换PO";
        }
    }
    public interface InvoiceNoticeBillItem {
        static String code() {
            return "invoiceNoticeBillItem";
        }
        static String name() {
            return "开票通知单明细页";
        }
    }
    public interface Event {
        static String code() {
            return "event";
        }
        static String name() {
            return "事件履历";
        }
    }
    public interface PayableDetail {
        static String code() {
            return "payableDetail";
        }
        static String name() {
            return "发票登记表-付款查询";
        }
    }
    public interface Email {
        static String code() {
            return "email";
        }
        static String name() {
            return "邮件履历";
        }
    }
    public interface InvoiceNoticeBill {
        static String code() {
            return "invoiceNoticeBill";
        }
        static String name() {
            return "开票通知单运维";
        }
    }
    public interface BuyerMapping {
        static String code() {
            return "buyerMapping";
        }
        static String name() {
            return "执行分公司工厂对照表";
        }
    }
    public interface DispatcherRuleConfig {
        static String code() {
            return "dispatcherRuleConfig";
        }
        static String name() {
            return "分发规则配置";
        }
    }
}

==> jc-tke-metadata-1.1.531-sources.jar: com/xforceplus/ultraman/app/jctke/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.jctke.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2023-02-09
 */

public class PageMeta {
    public interface PurchaseOrderManagement {
        static String code() {
            return "purchaseOrderManagement";
        }
        static String name() {
            return "采购单管理";
        }
    }
    public interface GoodsReceiptManagement {
        static String code() {
            return "goodsReceiptManagement";
        }
        static String name() {
            return "收货单运维";
        }
    }
    public interface InvoiceNotice {
        static String code() {
            return "invoiceNotice";
        }
        static String name() {
            return "开票通知单#供应商专用";
        }
    }
    public interface TaxCode {
        static String code() {
            return "taxCode";
        }
        static String name() {
            return "税码关系配置";
        }
    }
    public interface SubeiAmountApproval {
        static String code() {
            return "subeiAmountApproval";
        }
        static String name() {
            return "诉讼费备用金模板审批人规则";
        }
    }
    public interface ToubaoAmountApproval {
        static String code() {
            return "toubaoAmountApproval";
        }
        static String name() {
            return "投标保证金模板审批人规则";
        }
    }
    public interface WeiAmountApproval {
        static String code() {
            return "weiAmountApproval";
        }
        static String name() {
            return "维保金模板审批人规则";
        }
    }
    public interface RpaTask {
        static String code() {
            return "rpaTask";
        }
        static String name() {
            return "RPA任务表";
        }
    }
    public interface ProfitCenterCompany {
        static String code() {
            return "profitCenterCompany";
        }
        static String name() {
            return "利润中心分公司关系管理";
        }
    }
    public interface AdvanceChargeInterface {
        static String code() {
            return "advanceChargeInterface";
        }
        static String name() {
            return "预付款履历";
        }
    }
    public interface AccountsPayableInterface {
        static String code() {
            return "accountsPayableInterface";
        }
        static String name() {
            return "应付款履历";
        }
    }
    public interface ApprovalHistory {
        static String code() {
            return "approvalHistory";
        }
        static String name() {
            return "付款单操作履历";
        }
    }
    public interface Enclosure {
        static String code() {
            return "enclosure";
        }
        static String name() {
            return "附件表";
        }
    }
    public interface PaymentManage {
        static String code() {
            return "paymentManage";
        }
        static String name() {
            return "付款申请单";
        }
    }
    public interface PurchaseOrder {
        static String code() {
            return "purchaseOrder";
        }
        static String name() {
            return "采购单主信息列表";
        }
    }
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票登记表";
        }
    }
    public interface InvoiceNoticeBill4Payment {
        static String code() {
            return "invoiceNoticeBill4Payment";
        }
        static String name() {
            return "开票通知单#生成应付单专用";
        }
    }
    public interface PoList {
        static String code() {
            return "poList";
        }
        static String name() {
            return "采购单列表#含PO预付款";
        }
    }
    public interface ApprovalRules {
        static String code() {
            return "approvalRules";
        }
        static String name() {
            return "付款单审批规则";
        }
    }
    public interface CostCenter {
        static String code() {
            return "costCenter";
        }
        static String name() {
            return "成本中心管理(废弃)";
        }
    }
    public interface CostCenterNew {
        static String code() {
            return "costCenterNew";
        }
        static String name() {
            return "成本中心";
        }
    }
    public interface LegalFees {
        static String code() {
            return "legalFees";
        }
        static String name() {
            return "诉讼费列表";
        }
    }
    public interface MatchInvoiceNoticeBill {
        static String code() {
            return "matchInvoiceNoticeBill";
        }
        static String name() {
            return "开票通知单#非协同配单";
        }
    }
    public interface MacthInvoice {
        static String code() {
            return "macthInvoice";
        }
        static String name() {
            return "发票配单";
        }
    }
    public interface Wbs {
        static String code() {
            return "wbs";
        }
        static String name() {
            return "WBS梯台运维";
        }
    }
    public interface PoRpaTask {
        static String code() {
            return "poRpaTask";
        }
        static String name() {
            return "RPA任务列表#抓取PO";
        }
    }
    public interface AgentFeeReport {
        static String code() {
            return "agentFeeReport";
        }
        static String name() {
            return "PowerBI运维";
        }
    }
    public interface MultiValues {
        static String code() {
            return "multiValues";
        }
        static String name() {
            return "多值测试";
        }
    }
    public interface PurchaseOrderInit {
        static String code() {
            return "purchaseOrderInit";
        }
        static String name() {
            return "采购单运维";
        }
    }
    public interface PuchaserAndReceived {
        static String code() {
            return "puchaserAndReceived";
        }
        static String name() {
            return "采购单—收货单管理";
        }
    }
    public interface InvoiceOperation {
        static String code() {
            return "invoiceOperation";
        }
        static String name() {
            return "发票操作履历";
        }
    }
    public interface ExchangeTicketsMatch {
        static String code() {
            return "exchangeTicketsMatch";
        }
        static String name() {
            return "开票通知单#换票配单";
        }
    }
    public interface AdvancedOrder {
        static String code() {
            return "advancedOrder";
        }
        static String name() {
            return "预付款列表";
        }
    }
    public interface ReplacePOList {
        static String code() {
            return "replacePOList";
        }
        static String name() {
            return "采购单列表#替换PO";
        }
    }
    public interface InvoiceNoticeBillItem {
        static String code() {
            return "invoiceNoticeBillItem";
        }
        static String name() {
            return "开票通知单明细页";
        }
    }
    public interface Event {
        static String code() {
            return "event";
        }
        static String name() {
            return "事件履历";
        }
    }
    public interface PayableDetail {
        static String code() {
            return "payableDetail";
        }
        static String name() {
            return "发票登记表-付款查询";
        }
    }
    public interface Email {
        static String code() {
            return "email";
        }
        static String name() {
            return "邮件履历";
        }
    }
    public interface InvoiceNoticeBill {
        static String code() {
            return "invoiceNoticeBill";
        }
        static String name() {
            return "开票通知单运维";
        }
    }
    public interface BuyerMapping {
        static String code() {
            return "buyerMapping";
        }
        static String name() {
            return "执行分公司工厂对照表";
        }
    }
    public interface DispatcherRuleConfig {
        static String code() {
            return "dispatcherRuleConfig";
        }
        static String name() {
            return "定时待办分发规则配置";
        }
    }
    public interface Producer {
        static String code() {
            return "producer";
        }
        static String name() {
            return "定时待办运维";
        }
    }
    public interface NoticeBillHandleRecord {
        static String code() {
            return "noticeBillHandleRecord";
        }
        static String name() {
            return "开票通知单操作履历";
        }
    }
}
